@@ -1,9 +1,11 @@
-#include "mainwindow.h"
 #include <QApplication>
 #include <QLocale>
 #include <QLockFile>
 #include <QTranslator>
 
+#include "mainwindow.h"
+#include "version.h"
+
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
@@ -15,6 +17,10 @@ int main(int argc, char *argv[])
         return EXIT_FAILURE;
     }
 
+    QApplication::setWindowIcon(QIcon::fromTheme(QApplication::applicationName()));
+    QApplication::setOrganizationName("MX-Linux");
+    QApplication::setApplicationVersion(VERSION);
+
     QTranslator qtTran;
     qtTran.load(QString("qt_") + QLocale::system().name());
     QApplication::installTranslator(&qtTran);
