@@ -1,9 +1,12 @@
 #pragma once
 
+#include <QDBusConnection>
+#include <QDBusMessage>
 #include <QDialog>
 #include <QListWidgetItem>
 #include <QMenu>
 #include <QProcess>
+#include <QSettings>
 #include <QSystemTrayIcon>
 
 namespace Ui
@@ -24,8 +27,9 @@ class MainWindow : public QDialog
 public:
     explicit MainWindow(const QString &arg1, QWidget *parent = nullptr);
     ~MainWindow() override;
-    void start();
     void about();
+    void listDevices();
+    void start();
     Output runCmd(const QString &cmd);
     QString UID;
 
@@ -35,6 +39,9 @@ private slots:
     void iconActivated(QSystemTrayIcon::ActivationReason reason);
     void keyPressEvent(QKeyEvent *event) override;
     void mountlistviewItemActivated(QListWidgetItem *item);
+    void onInterfacesRemoved(const QDBusMessage &message);
+    void toggleAutostart();
+    void toggleHideIcon();
 
 private:
     Ui::MainWindow *ui;
@@ -43,13 +50,21 @@ private:
     QAction *listDevicesAction {};
     QAction *quitAction {};
     QAction *toggleAutostartAction {};
+    QAction *toggleHideAction {};
+    QDBusConnection *systemBus {};
     QMenu *menu {};
     QProcess proc;
+    QSettings settings;
     QSystemTrayIcon *trayIcon {};
+    const QString serviceName = "org.freedesktop.UDisks2";
+    const QString objectPath = "/org/freedesktop/UDisks2";
+    const QString interfaceName = "org.freedesktop.DBus.ObjectManager";
 
+    bool hasDevices();
     static void help();
     void createActions();
     void createMenu();
+    void disconnectFromDBus();
     void setPosition();
-    void toggleAutostart();
+    void deviceMonitor();
 };
